"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const process = require("process");
const utils_1 = require("./utils");
const isDevelopment = process.env.NODE_ENV === 'development';
function babelPresetSweet(api, options = {}, dirname) {
    const { env, typescript, react } = options;
    const { nodeEnv, ecmascript, targets: customTargets, debug, modules, useBuiltIns } = env !== null && env !== void 0 ? env : {}, { use: useTypescript, isReact = true } = typescript !== null && typescript !== void 0 ? typescript : {}, { use: useReact = true, runtime, development } = react !== null && react !== void 0 ? react : {};
    const presets = [], plugins = [
        ...utils_1.defaultPlugins,
        [
            '@babel/plugin-transform-runtime',
            {
                corejs: { version: 3, proposals: true },
                helpers: true,
                regenerator: nodeEnv || !ecmascript,
                useESModules: true
            }
        ]
    ];
    // 添加@babel/preset-env
    if (!ecmascript) {
        const useBuiltInsValue = useBuiltIns !== null && useBuiltIns !== void 0 ? useBuiltIns : 'usage';
        const options = {
            targets: customTargets !== null && customTargets !== void 0 ? customTargets : {
                browsers: nodeEnv ? ['node 10'] : [
                    'last 2 versions',
                    'last 10 Chrome versions',
                    'last 1 year',
                    'IE 11'
                ]
            },
            debug,
            modules: modules !== null && modules !== void 0 ? modules : false,
            useBuiltIns: useBuiltInsValue,
            bugfixes: true
        };
        if (useBuiltInsValue) {
            options.corejs = 3;
        }
        presets.push(['@babel/preset-env', options]);
    }
    // 添加@babel/preset-react
    if (useReact) {
        presets.push([
            '@babel/preset-react',
            {
                runtime: (runtime !== null && runtime !== void 0 ? runtime : utils_1.moduleExists('react/jsx-runtime')) ? 'automatic' : 'classic',
                development: development !== null && development !== void 0 ? development : isDevelopment
            }
        ]);
    }
    // 添加@babel/preset-typescript
    if (useTypescript) {
        presets.push([
            '@babel/preset-typescript',
            {
                isTSX: true,
                jsxPragma: isReact ? 'React' : 'Preserve',
                allExtensions: true,
                allowNamespaces: true
            }
        ]);
    }
    return { presets, plugins };
}
exports.default = babelPresetSweet;
